export declare type ChildFolderWriteGrants = {
    /**
     * INVARIANT:
     *
     * makeFolder || !childFile.create
     *
     * IN ENGLISH:
     *
     * Prevents 'makeFolder' from being FALSE if you are able to create a file.
     *
     * EXPLANATION:
     *
     * This relationship acknowledges that folder creation can occur as its own action _AND_ is also a side effect of
     * uploading files to non-existent sub-folders. The latter is particularly important, as enforcing the acknowledgement
     * that folders are created as a side effect of file creation means we don't need to check for the existence of folders
     * during file creation for the purpose of raising auth errors if the folder doesn't exist. Rather, with this
     * relationship enforced, we can just continue to create the file and the potential hierarchy of folders that come
     * with it.
     */
    makeFolder: boolean;
};
