import type { AccountId } from "../models/AccountId";
import type { AsyncResponse } from "../models/AsyncResponse";
import type { DeleteFolder } from "../models/DeleteFolder";
import type { FolderPath } from "../models/FolderPath";
import type { ListFolderChildrenCursor } from "../models/ListFolderChildrenCursor";
import type { ListFolderChildrenResult } from "../models/ListFolderChildrenResult";
import type { MakeFolder } from "../models/MakeFolder";
export declare class FoldersService {
    /**
     * Creates or updates a folder (recursively).
     *
     * If ancestor folders are missing, they will be created with default settings.
     *
     * If no physical folder exists and 'createPhysicalFolder' is true, creates a physical folder if the storage layer supports it.
     *
     * If folder settings already exist, they will be overwritten (if permissions allow it), else they will be created (if permissions allow it).
     *
     * If at any point permissions deny the operation, a 403 error will be returned.
     * @param accountId
     * @param requestBody
     * @returns any Success.
     * @throws ApiError
     */
    static makeFolder(accountId: AccountId, requestBody: MakeFolder): Promise<any>;
    /**
     * @param accountId
     * @param requestBody
     * @returns AsyncResponse Success.
     * @throws ApiError
     */
    static deleteFolder(accountId: AccountId, requestBody: DeleteFolder): Promise<AsyncResponse>;
    /**
     * @param accountId
     * @param path
     * @param external
     * @param folders
     * @param files
     * @param cursor
     * @returns ListFolderChildrenResult Success.
     * @throws ApiError
     */
    static list(accountId: AccountId, path: FolderPath, external?: boolean, folders?: boolean, files?: boolean, cursor?: ListFolderChildrenCursor): Promise<ListFolderChildrenResult>;
}
