/* istanbul ignore file */
/* tslint:disable */
/* eslint-disable */
import type { AccountId } from "../models/AccountId";
import type { AsyncResponse } from "../models/AsyncResponse";
import type { DeleteFolder } from "../models/DeleteFolder";
import type { FolderPath } from "../models/FolderPath";
import type { ListFolderChildrenCursor } from "../models/ListFolderChildrenCursor";
import type { ListFolderChildrenResult } from "../models/ListFolderChildrenResult";
import type { MakeFolder } from "../models/MakeFolder";
import { request as __request } from "../core/request";

export class FoldersService {
  /**
   * Creates or updates a folder (recursively).
   *
   * If ancestor folders are missing, they will be created with default settings.
   *
   * If no physical folder exists and 'createPhysicalFolder' is true, creates a physical folder if the storage layer supports it.
   *
   * If folder settings already exist, they will be overwritten (if permissions allow it), else they will be created (if permissions allow it).
   *
   * If at any point permissions deny the operation, a 403 error will be returned.
   * @param accountId
   * @param requestBody
   * @returns any Success.
   * @throws ApiError
   */
  public static async makeFolder(accountId: AccountId, requestBody: MakeFolder): Promise<any> {
    const result = await __request({
      method: "PUT",
      path: `/v1/accounts/${accountId}/folders`,
      body: requestBody,
      mediaType: "application/json",
      errors: {
        401: `Unauthenticated.`
      }
    });
    return result.body;
  }

  /**
   * @param accountId
   * @param requestBody
   * @returns AsyncResponse Success.
   * @throws ApiError
   */
  public static async deleteFolder(accountId: AccountId, requestBody: DeleteFolder): Promise<AsyncResponse> {
    const result = await __request({
      method: "DELETE",
      path: `/v1/accounts/${accountId}/folders`,
      body: requestBody,
      mediaType: "application/json",
      errors: {
        401: `Unauthenticated.`
      }
    });
    return result.body;
  }

  /**
   * @param accountId
   * @param path
   * @param external
   * @param folders
   * @param files
   * @param cursor
   * @returns ListFolderChildrenResult Success.
   * @throws ApiError
   */
  public static async list(
    accountId: AccountId,
    path: FolderPath,
    external?: boolean,
    folders?: boolean,
    files?: boolean,
    cursor?: ListFolderChildrenCursor
  ): Promise<ListFolderChildrenResult> {
    const result = await __request({
      method: "GET",
      path: `/v1/accounts/${accountId}/folders/children`,
      query: {
        path: path,
        external: external,
        folders: folders,
        files: files,
        cursor: cursor
      },
      errors: {
        401: `Unauthenticated.`
      }
    });
    return result.body;
  }
}
